#!/usr/bin/env python

import os
import sys
import getopt
import shutil

usage_info = """This script installs or uninstalls Comix on your system.
If you encounter any bugs, please report them to herrekberg@users.sf.net.

Usage:

 ./install.py install              ---      Install to /usr/local

 ./install.py uninstall            ---      Uninstall from /usr/local

Options:

 --installdir <directory>          ---      Install or uninstall in <directory>
                                            instead of /usr/local

 --no-mime                         ---      Do not register new mime types
                                            for x-cbz, x-cbt and x-cbr
                                            archive files.
"""

def info():
    print usage_info
    sys.exit(1)

def install(src, dst):
    try:
        dst = os.path.join(install_dir, dst)
        assert os.path.isfile(src)
        assert not os.path.isdir(dst)
        if not os.path.isdir(os.path.dirname(dst)):
            os.makedirs(os.path.dirname(dst))
        shutil.copy(src, dst)
        print "Installed", dst
    except:
        print "Error while installing", dst

def uninstall(path):
    try:
        path = os.path.join(install_dir, path)
        if os.path.isfile(path):
            os.remove(path)
        elif os.path.isdir(path):
            shutil.rmtree(path)
        else:
            return
        print "Removed", path
    except:
        print "Error while removing", path

def check_dependencies():
    print "Checking dependencies..."
    # Should also check the PyGTK version. To do that we have to load the
    # gtk module though, which normally can't be done while using `sudo`.
    try:
        import pygtk
        print "PyGTK ........................ OK"
    except ImportError:
        print "!!! PyGTK .................... Not found"
    try:
        import Image
        assert Image.VERSION >= "1.1.4"
        print "Python Imaging Library ....... OK"
    except ImportError:
        print "!!! Python Imaging Library ... Not found"
    except AssertionError:
        print "!!! Python Imaging Library ... version", Image.VERSION, "found"
        print "!!! Python Imaging Library 1.1.4 or higher is required"
    # rar/unrar is only a requirement to read RAR (.cbr) files.
    rar = False
    for path in os.getenv("PATH").split(":"):
        if (os.path.isfile(os.path.join(path, "unrar")) or
            os.path.isfile(os.path.join(path, "rar"))):
            print "rar/unrar .................... OK"
            rar = True
            break
    if not rar:
        print "!!! rar/unrar ................ Not found"
    # jpegtran is only a requirement to rotate JPEG files.
    jpegtran = False
    for path in os.getenv("PATH").split(":"):
        if os.path.isfile(os.path.join(path, "jpegtran")):
            print "jpegtran  .................... OK"
            jpegtran = True
            break
    if not jpegtran:
        print "!!! jpegtran  ................ Not found"




install_dir = "/usr/local/"
no_mime = False
ISO_CODES = \
    ("sv", "es", "zh_CN", "zh_TW", "pt_BR", "de", "it", "nl", "fr", "pl",
    "el", "ca")

try:
    opts, args = \
        getopt.gnu_getopt(sys.argv[1:], "", ["installdir=", "no-mime"])
except getopt.GetoptError:
    info()
for opt, value in opts:
    if opt == "--installdir":
        install_dir = value
        if not os.path.isdir(install_dir):
            info()
    elif opt == "--no-mime":
        no_mime = True

if args == ["install"]:
    check_dependencies()
    print
    install("comix", "bin/comix")
    install("comix.1.gz", "share/man/man1/comix.1.gz")
    install("comix.desktop", "share/applications/comix.desktop")
    install("images/comix.png", "share/pixmaps/comix.png")
    install("images/comix.png", "share/icons/hicolor/48x48/apps/comix.png")
    install("images/comix.svg", "share/icons/hicolor/scalable/apps/comix.svg")
    install("images/flip-horizontal.png",
        "share/pixmaps/comix/flip-horizontal.png")
    install("images/flip-vertical.png", "share/pixmaps/comix/flip-vertical.png")
    install("images/rotate-90.png", "share/pixmaps/comix/rotate-90.png")
    install("images/rotate-180.png", "share/pixmaps/comix/rotate-180.png")
    install("images/rotate-270.png", "share/pixmaps/comix/rotate-270.png")
    install("images/rotate-90-jpeg.png",
        "share/pixmaps/comix/rotate-90-jpeg.png")
    install("images/rotate-270-jpeg.png",
        "share/pixmaps/comix/rotate-270-jpeg.png")
    install("images/library.png", "share/pixmaps/comix/library.png")
    install("images/library_add.png", "share/pixmaps/comix/library_add.png")
    install("images/slideshow.png", "share/pixmaps/comix/slideshow.png")
    install("images/double_page.png", "share/pixmaps/comix/double_page.png")
    install("images/fitheight.png", "share/pixmaps/comix/fitheight.png")
    install("images/fitnone.png", "share/pixmaps/comix/fitnone.png")
    install("images/fitscreen.png", "share/pixmaps/comix/fitscreen.png")
    install("images/fitwidth.png", "share/pixmaps/comix/fitwidth.png")
    install("images/lens.png", "share/pixmaps/comix/lens.png")
    install("images/manga.png", "share/pixmaps/comix/manga.png")
    install("images/cbz.png", "share/pixmaps/comix/cbz.png")
    install("images/cbt.png", "share/pixmaps/comix/cbt.png")
    install("images/cbr.png", "share/pixmaps/comix/cbr.png")
    for lang in ISO_CODES:
        install("messages/" + lang + "/LC_MESSAGES/comix.mo",
            "share/locale/" + lang + "/LC_MESSAGES/comix.mo")
    if not no_mime:
        install("mime/comicthumb", "bin/comicthumb")
        install("mime/comicthumb.1.gz", "share/man/man1/comicthumb.1.gz")
        install("mime/comix.xml", "share/mime/packages/comix.xml")
        os.popen("update-mime-database '" + 
            os.path.join(install_dir, "share/mime'"))
        print
        print "Updated mime database."
        os.popen("export GCONF_CONFIG_SOURCE=`gconftool-2 "
                 "--get-default-source 2>/dev/null` && gconftool-2 "
                 "--makefile-install-rule ./mime/comicbook.schemas 2>/dev/null")
        print
        print "Registered comic archive thumbnailer in gconf (if available)."
        print "The thumbnailer is at this point supported by Nautilus only."
        print "You have to restart Nautilus before it is activated."
elif args == ["uninstall"]:
    uninstall("bin/comix")
    uninstall("share/man/man1/comix.1.gz")
    uninstall("share/applications/comix.desktop")
    uninstall("share/pixmaps/comix.png")
    uninstall("share/icons/hicolor/48x48/apps/comix.png")
    uninstall("share/icons/hicolor/scalable/apps/comix.svg")
    uninstall("share/pixmaps/comix/flip-horizontal.png")
    uninstall("share/pixmaps/comix/flip-vertical.png")
    uninstall("share/pixmaps/comix/rotate-90.png")
    uninstall("share/pixmaps/comix/rotate-180.png")
    uninstall("share/pixmaps/comix/rotate-270.png")
    uninstall("share/pixmaps/comix/rotate-90-jpeg.png")
    uninstall("share/pixmaps/comix/rotate-270-jpeg.png")
    uninstall("share/pixmaps/comix/library.png")
    uninstall("share/pixmaps/comix/library_add.png")
    uninstall("share/pixmaps/comix/slideshow.png")
    uninstall("share/pixmaps/comix/double_page.png")
    uninstall("share/pixmaps/comix/fitheight.png")
    uninstall("share/pixmaps/comix/fitnone.png")
    uninstall("share/pixmaps/comix/fitscreen.png")
    uninstall("share/pixmaps/comix/fitwidth.png")
    uninstall("share/pixmaps/comix/lens.png")
    uninstall("share/pixmaps/comix/manga.png")
    uninstall("share/pixmaps/comix/cbz.png")
    uninstall("share/pixmaps/comix/cbt.png")
    uninstall("share/pixmaps/comix/cbr.png")
    uninstall("share/pixmaps/comix")
    uninstall("bin/comicthumb")
    uninstall("share/man/man1/comicthumb.1.gz")
    uninstall("share/mime/packages/comix.xml")
    for lang in ISO_CODES:
        uninstall("share/locale/" + lang + "/LC_MESSAGES/comix.mo")
    uninstall("/tmp/comix")
    print
    print "There might still be files in ~/.comix/ left on your system."
    print "Please remove that directory manually if you do not plan to"
    print "install Comix again later."
    
else:
    info()

